@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <fcntl.h>
@@ -60,8 +39,8 @@ command_source_add_sink (Source      *self,
     CommandSource *src = COMMAND_SOURCE (self);
     GValue value = G_VALUE_INIT;
 
-    g_debug ("command_source_add_sink: CommandSource: 0x%" PRIxPTR
-             " , Sink: 0x%" PRIxPTR, (uintptr_t)src, (uintptr_t)sink);
+    g_debug ("command_source_add_sink: CommandSource: %p, Sink: %p",
+             objid (src), objid (sink));
     g_value_init (&value, G_TYPE_OBJECT);
     g_value_set_object (&value, sink);
     g_object_set_property (G_OBJECT (src), "sink", &value);
@@ -130,11 +109,11 @@ command_source_set_property (GObject       *object,
 {
     CommandSource *self = COMMAND_SOURCE (object);
 
-    g_debug ("command_source_set_properties: 0x%" PRIxPTR, (uintptr_t)self);
+    g_debug ("command_source_set_properties: %p", objid (self));
     switch (property_id) {
     case PROP_COMMAND_ATTRS:
         self->command_attrs = COMMAND_ATTRS (g_value_dup_object (value));
-        g_debug ("  command_attrs: 0x%" PRIxPTR, (uintptr_t)self->command_attrs);
+        g_debug ("  command_attrs: %p", objid (self->command_attrs));
         break;
     case PROP_CONNECTION_MANAGER:
         self->connection_manager = CONNECTION_MANAGER (g_value_get_object (value));
@@ -147,7 +126,7 @@ command_source_set_property (GObject       *object,
         }
         self->sink = SINK (g_value_get_object (value));
         g_object_ref (self->sink);
-        g_debug ("  sink: 0x%" PRIxPTR, (uintptr_t)self->sink);
+        g_debug ("  sink: %p", objid (self->sink));
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -163,7 +142,7 @@ command_source_get_property (GObject      *object,
 {
     CommandSource *self = COMMAND_SOURCE (object);
 
-    g_debug ("command_source_get_properties: 0x%" PRIxPTR, (uintptr_t)self);
+    g_debug ("command_source_get_properties: %p", objid (self));
     switch (property_id) {
     case PROP_COMMAND_ATTRS:
         g_value_set_object (value, self->command_attrs);
@@ -202,18 +181,17 @@ command_source_on_input_ready (GInputStream *istream,
     uint8_t       *buf;
     size_t         buf_size;
 
-    g_debug ("%s: GInputStream: 0x%" PRIxPTR ", CommandSource: 0x%" PRIxPTR,
-             __func__, (uintptr_t)istream, (uintptr_t)data->self);
+    g_debug ("%s: GInputStream: %p, CommandSource: %p",
+             __func__, objid (istream), objid (data->self));
     connection =
         connection_manager_lookup_istream (data->self->connection_manager,
                                            istream);
     if (connection == NULL) {
-        g_error ("failed to get connection associated with istream: 0x%"
-                 PRIxPTR, (uintptr_t)istream);
+        g_error ("failed to get connection associated with istream: %p",
+                 objid (istream));
     } else {
-        g_debug ("connection_manager_lookup_socket for socket: 0x%" PRIxPTR
-                 ", connection: 0x%" PRIxPTR, (uintptr_t)istream,
-                 (uintptr_t)connection);
+        g_debug ("connection_manager_lookup_socket for socket: %p, "
+                 "connection: %p", objid (istream), objid (connection));
     }
     buf = read_tpm_buffer_alloc (istream, &buf_size);
     if (buf == NULL) {
@@ -235,10 +213,8 @@ fail_out:
     if (buf != NULL) {
         g_free (buf);
     }
-    g_debug ("removing connection 0x%" PRIxPTR " from connection_manager "
-             "0x%" PRIxPTR,
-             (uintptr_t)connection,
-             (uintptr_t)data->self->connection_manager);
+    g_debug ("removing connection %p from connection_manager %p",
+             objid (connection), objid (data->self->connection_manager));
     connection_manager_remove (data->self->connection_manager,
                                connection);
     ControlMessage *msg =
@@ -253,7 +229,7 @@ fail_out:
      * since we're letting this source die at the end of this function
      * (returning FALSE).
      */
-    g_debug ("%s: reomvingunref GCancellable: 0x%" PRIxPTR, __func__, (uintptr_t)data->cancellable);
+    g_debug ("%s: reomvingunref GCancellable: %p", __func__, objid (data->cancellable));
     g_hash_table_remove (data->self->istream_to_source_data_map, istream);
     return G_SOURCE_REMOVE;
 }
@@ -272,7 +248,7 @@ command_source_on_new_connection (ConnectionManager   *connection_manager,
     source_data_t *data;
     UNUSED_PARAM(connection_manager);
 
-    g_info ("%s: adding new connection: 0x%" PRIxPTR, __func__, (uintptr_t)connection);
+    g_info ("%s: adding new connection: %p", __func__, objid (connection));
     /*
      * Take reference to socket, will be freed when the source_data_t
      * structure is freed
@@ -316,9 +292,8 @@ command_source_source_cancel (gpointer key,
     g_debug ("%s", __func__);
     source_data_t *data = (source_data_t*)value;
 
-    g_debug ("%s: canceling cancellable: 0x%" PRIxPTR " and destroying "
-             "source: 0x%" PRIxPTR, __func__, (uintptr_t)data->cancellable,
-             (uintptr_t)data->source);
+    g_debug ("%s: canceling cancellable: %p" " and destroying source: %p",
+             __func__, objid (data->cancellable), objid (data->source));
     g_cancellable_cancel (data->cancellable);
 }
 /*
