@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
- * Copyright (c) 2017, Intel Corporation
+ * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include <gio/gunixfdlist.h>
@@ -185,8 +164,8 @@ ipc_frontend_dbus_class_init (IpcFrontendDbusClass *klass)
                           "maximum transient objects",
                           "maximum number of transient objects for the handle map",
                           1,
-                          MAX_TRANSIENT_OBJECTS,
-                          MAX_TRANSIENT_OBJECTS_DEFAULT,
+                          TABRMD_TRANSIENT_MAX,
+                          TABRMD_TRANSIENT_MAX_DEFAULT,
                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     obj_properties [PROP_RANDOM] =
         g_param_spec_object ("random",
@@ -276,7 +255,7 @@ get_pid_from_dbus_invocation (GDBusProxy            *proxy,
     }
 }
 /*
- * Generate a random uint64 returned in the id out paramter.
+ * Generate a random uint64 returned in the id out parameter.
  * Mix this random ID with the PID from the caller. This is obtained
  * through the invocation parameter. Mix the two together using xor and
  * return the result through the id_pid_mix out parameter.
@@ -369,6 +348,7 @@ on_handle_create_connection (TctiTabrmd            *skeleton,
     GUnixFDList *fd_list = NULL;
     guint64 id = 0, id_pid_mix = 0;
     gboolean id_ret = FALSE;
+    UNUSED_PARAM(skeleton);
 
     self = IPC_FRONTEND_DBUS (user_data);
     ipc_frontend_init_guard (IPC_FRONTEND (user_data));
@@ -398,7 +378,7 @@ on_handle_create_connection (TctiTabrmd            *skeleton,
             "Failed to allocate connection ID. Try again later.");
         return TRUE;
     }
-    handle_map = handle_map_new (TPM_HT_TRANSIENT, self->max_transient_objects);
+    handle_map = handle_map_new (TPM2_HT_TRANSIENT, self->max_transient_objects);
     if (handle_map == NULL)
         g_error ("Failed to allocate new HandleMap");
     iostream = create_connection_iostream (&client_fd);
@@ -435,11 +415,11 @@ on_handle_create_connection (TctiTabrmd            *skeleton,
 }
 /*
  * This is a signal handler for the Cancel event emitted by the
- * Tpm2AcessBroker. It is invoked by a signal generated by a user
+ * Tpm2 AccessBroker. It is invoked by a signal generated by a user
  * requesting that an outstanding TPM command should be canceled. It is
  * registered with the Tabrmd in response to acquiring a name
  * on the dbus (on_name_acquired). It does X things:
- * - Locate the Connection object associted with the 'id' parameter in
+ * - Locate the Connection object associated with the 'id' parameter in
  *   the ConnectionManager.
  * - If the connection has a command being processed by the tabrmd then it's
  *   removed from the processing queue.
@@ -458,6 +438,7 @@ on_handle_cancel (TctiTabrmd            *skeleton,
     Connection *connection = NULL;
     guint64   id_pid_mix = 0;
     gboolean mix_ret = FALSE;
+    UNUSED_PARAM(skeleton);
 
     g_info ("on_handle_cancel for id 0x%" PRIx64, id);
     ipc_frontend_init_guard (IPC_FRONTEND (self));
@@ -480,8 +461,8 @@ on_handle_cancel (TctiTabrmd            *skeleton,
                                                "No connection.");
         return TRUE;
     }
-    g_info ("canceling command for connection 0x%" PRIxPTR " with "
-            "id_pid_mix: 0x%" PRIx64, (uintptr_t)connection, id_pid_mix);
+    g_info ("canceling command for connection %p" " with "
+            "id_pid_mix: 0x%" PRIx64, objid (connection), id_pid_mix);
     /* cancel any existing commands for the connection */
     g_dbus_method_invocation_return_error (invocation,
                                            TABRMD_ERROR,
@@ -511,6 +492,7 @@ on_handle_set_locality (TctiTabrmd            *skeleton,
     Connection *connection = NULL;
     guint64   id_pid_mix = 0;
     gboolean mix_ret = FALSE;
+    UNUSED_PARAM(skeleton);
 
     g_info ("on_handle_set_locality for id 0x%" PRIx64, id);
     ipc_frontend_init_guard (IPC_FRONTEND (self));
@@ -533,9 +515,8 @@ on_handle_set_locality (TctiTabrmd            *skeleton,
                                                "No connection.");
         return TRUE;
     }
-    g_info ("setting locality for connection 0x%" PRIxPTR " with "
-            "id_pid_mix: 0x%" PRIx64 " to: %" PRIx8,
-            (uintptr_t)connection, id_pid_mix, locality);
+    g_info ("setting locality for connection %p with id_pid_mix: 0x%" PRIx64
+            " to: %" PRIx8, objid (connection), id_pid_mix, locality);
     /* set locality for an existing connection */
     g_dbus_method_invocation_return_error (invocation,
                                            TABRMD_ERROR,
@@ -548,7 +529,7 @@ on_handle_set_locality (TctiTabrmd            *skeleton,
 /* D-Bus signal handlers */
 /*
  * This is a signal handler of type GBusAcquiredCallback. It is registered
- * by the g_bus_own_name function and invoked then a connectiont to a bus
+ * by the g_bus_own_name function and invoked then a connection to a bus
  * is acquired in response to a request for the parameter 'name'.
  */
 static void
@@ -556,6 +537,8 @@ on_bus_acquired (GDBusConnection *connection,
                  const gchar     *name,
                  gpointer         user_data)
 {
+    UNUSED_PARAM(connection);
+    UNUSED_PARAM(user_data);
     g_info ("on_bus_acquired: %s", name);
 }
 /*
@@ -619,10 +602,12 @@ on_name_lost (GDBusConnection *connection,
     g_debug ("%s: %s", __func__, name);
     IpcFrontend *ipc_frontend = IPC_FRONTEND (user_data);
     IpcFrontendDbus *self = IPC_FRONTEND_DBUS (user_data);
+    UNUSED_PARAM(connection);
 
     if (self->dbus_name_acquired == FALSE) {
         g_critical ("Failed to acquire DBus name %s. UID %d must be "
-                    "allowed to \"own\" this name. Check DBus config.",
+                    "allowed to \"own\" this name. Check DBus config "
+                    "and check that this is running as user tss or root.",
                     name, getuid ());
     } else {
         self->dbus_name_acquired = FALSE;
@@ -642,6 +627,7 @@ on_get_dbus_daemon_proxy (GObject      *source_object,
 {
     GError *error = NULL;
     IpcFrontendDbus *self = IPC_FRONTEND_DBUS (user_data);
+    UNUSED_PARAM(source_object);
 
     self->dbus_daemon_proxy = g_dbus_proxy_new_finish (result, &error);
     if (error) {
