@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <glib.h>
@@ -103,7 +82,7 @@ response_sink_get_property (GObject     *object,
 {
     ResponseSink *self = RESPONSE_SINK (object);
 
-    g_debug ("response_sink_get_property: 0x%" PRIxPTR, (uintptr_t)self);
+    g_debug ("%s: %p", __func__, objid (self));
     switch (property_id) {
     case PROP_IN_QUEUE:
         g_value_set_object (value, self->in_queue);
@@ -122,7 +101,7 @@ response_sink_dispose (GObject *obj)
     ResponseSink *sink = RESPONSE_SINK (obj);
     Thread *thread = THREAD (obj);
 
-    g_debug ("%s: 0x%" PRIxPTR, __func__, (uintptr_t)obj);
+    g_debug ("%s: %p", __func__, objid (obj));
     if (sink == NULL)
         g_error ("%s: passed NULL pointer", __func__);
     if (thread->thread_id != 0)
@@ -144,10 +123,9 @@ response_sink_unblock (Thread *self)
     ControlMessage *msg;
 
     if (sink == NULL)
-        g_error ("response_sink_cancel passed NULL sink");
+        g_error ("%s: passed NULL sink", __func__);
     msg = control_message_new (CHECK_CANCEL);
-    g_debug ("response_sink_cancel enqueuing ControlMessage: 0x%" PRIxPTR,
-             (uintptr_t)msg);
+    g_debug ("%s: enqueuing ControlMessage: %p", __func__, objid (msg));
     message_queue_enqueue (sink->in_queue, G_OBJECT (msg));
     g_object_unref (msg);
 }
@@ -211,8 +189,7 @@ response_sink_process_response (Tpm2Response *response)
     GIOStream   *iostream = connection_get_iostream (connection);
     GOutputStream *ostream = g_io_stream_get_output_stream (iostream);
 
-    g_debug ("response_sink_thread got response: 0x%" PRIxPTR " size %d",
-             (uintptr_t)response, size);
+    g_debug ("%s: got response: %p size %d", __func__, objid (response), size);
     g_debug ("  writing 0x%x bytes", size);
     g_debug_bytes (buffer, size, 16, 4);
     written = write_all (ostream, buffer, size);
@@ -253,10 +230,10 @@ response_sink_thread (void *data)
     gboolean done = FALSE;
 
     while (!done) {
-        g_debug ("response_sink_thread blocking on input queue: 0x%" PRIxPTR,
-                 (uintptr_t)sink->in_queue);
+        g_debug ("%s: blocking on input queue: %p", __func__,
+                 objid (sink->in_queue));
         obj = message_queue_dequeue (sink->in_queue);
-        g_debug ("response_sink_thread got obj: 0x%" PRIxPTR, (uintptr_t)obj);
+        g_debug ("%s: got obj: %p", __func__, objid (obj));
         if (IS_TPM2_RESPONSE (obj)) {
             response_sink_process_response (TPM2_RESPONSE (obj));
         } else if (IS_CONTROL_MESSAGE (obj)) {
