@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <assert.h>
 #include <inttypes.h>
@@ -120,7 +99,7 @@ session_entry_dispose (GObject *object)
 {
     SessionEntry *entry = SESSION_ENTRY (object);
 
-    g_debug ("%s: 0x%" PRIxPTR, __func__, (uintptr_t)entry);
+    g_debug ("%s: %p", __func__, objid (entry));
     g_clear_object (&entry->connection);
     G_OBJECT_CLASS (session_entry_parent_class)->dispose (object);
 }
@@ -174,8 +153,8 @@ SessionEntry*
 session_entry_new (Connection *connection,
                    TPM2_HANDLE  handle)
 {
-    g_debug ("session_entry_new with connection: 0x%" PRIxPTR,
-             (uintptr_t)connection);
+    g_debug ("session_entry_new with connection: %p",
+             objid (connection));
     return SESSION_ENTRY (g_object_new (TYPE_SESSION_ENTRY,
                                         "connection", connection,
                                         "handle", handle,
@@ -225,8 +204,8 @@ get_handle (size_buf_t *size_buf)
                                         &offset,
                                         &handle);
     if (rc != TSS2_RC_SUCCESS) {
-        g_debug ("%s: Failed to unmarshal handle from size_buf_t 0x%"
-                   PRIxPTR, __func__, (uintptr_t)size_buf);
+        g_debug ("%s: Failed to unmarshal handle from size_buf_t %p",
+                 __func__, objid (size_buf));
         return 0;
     }
     g_debug ("%s: unmarshalled handle 0x08%" PRIx32, __func__, handle);
@@ -239,14 +218,14 @@ TPM2_HANDLE
 session_entry_get_handle (SessionEntry *entry)
 {
     g_assert_nonnull (entry);
-    g_debug ("%s: with SessionEntry 0x%" PRIxPTR, __func__, (uintptr_t)entry);
+    g_debug ("%s: with SessionEntry %p", __func__, objid (entry));
     return entry->handle;
 }
 TPM2_HANDLE
 session_entry_get_context_client_handle (SessionEntry *entry)
 {
     g_assert_nonnull (entry);
-    g_debug ("%s: with SessionEntry 0x%" PRIxPTR, __func__, (uintptr_t)entry);
+    g_debug ("%s: with SessionEntry %p", __func__, objid (entry));
     return get_handle (session_entry_get_context_client (entry));
 }
 /*
@@ -313,13 +292,12 @@ session_entry_clear_connection (SessionEntry *entry)
 void
 session_entry_prettyprint (SessionEntry *entry)
 {
-    g_debug ("SessionEntry:    0x%"   PRIxPTR, (uintptr_t)entry);
-    g_debug ("  Connection:    0x%"   PRIxPTR, (uintptr_t)entry->connection);
-    g_debug ("  State:         %s",   session_entry_state_to_str (entry->state));
-    g_debug ("  context:       0x%"   PRIxPTR,
-             (uintptr_t)session_entry_get_context (entry));
-    g_debug ("  context_client:0x%"   PRIxPTR,
-             (uintptr_t)session_entry_get_context_client (entry));
+    g_debug ("SessionEntry:    %p", objid (entry));
+    g_debug ("  Connection:    %p", objid (entry->connection));
+    g_debug ("  State:         %s", session_entry_state_to_str (entry->state));
+    g_debug ("  context:       %p", objid (session_entry_get_context (entry)));
+    g_debug ("  context_client:%p",
+             objid (session_entry_get_context_client (entry)));
 }
 /*
  * This function is used with the g_list_find_custom function to find
@@ -418,8 +396,8 @@ session_entry_compare_on_context_client (SessionEntry *entry,
 {
     size_buf_t *size_buf = NULL;
 
-    g_debug ("%s: SessionEntry 0x%" PRIxPTR ", buf 0x%" PRIxPTR " and size "
-             "0x%zx", __func__, (uintptr_t)entry, (uintptr_t)buf, size);
+    g_debug ("%s: SessionEntry %p, buf %p and size 0x%zx", __func__,
+             objid (entry), objid (buf), size);
     g_assert (size <= SIZE_BUF_MAX);
     size_buf = session_entry_get_context_client (entry);
     return memcmp (size_buf->buf, buf, size);
