@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017 - 2018 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <fcntl.h>
@@ -49,7 +28,8 @@
 #include "resource-manager.h"
 #include "response-sink.h"
 #include "source-interface.h"
-#include "tcti-dynamic.h"
+#include "tcti-factory.h"
+#include "tcti.h"
 #include "util.h"
 
 /* work around older glib versions missing this symbol */
@@ -70,7 +50,6 @@ typedef struct gmain_data {
     Random                 *random;
     ResponseSink           *response_sink;
     GMutex                  init_mutex;
-    Tcti                   *tcti;
     IpcFrontend            *ipc_frontend;
 } gmain_data_t;
 
@@ -104,7 +83,7 @@ static void
 on_ipc_frontend_disconnect (IpcFrontend *ipc_frontend,
                             GMainLoop   *loop)
 {
-    g_info ("IpcFrontend 0x%" PRIxPTR " disconnected", (uintptr_t)ipc_frontend);
+    g_info ("%s: IpcFrontend %p disconnected", __func__, objid (ipc_frontend));
     main_loop_quit (loop);
 }
 /**
@@ -134,6 +113,8 @@ init_thread_func (gpointer user_data)
     CommandAttrs *command_attrs;
     ConnectionManager *connection_manager = NULL;
     SessionList *session_list;
+    Tcti *tcti = NULL;
+    TctiFactory *tcti_factory = NULL;
 
     g_info ("init_thread_func start");
     g_mutex_lock (&data->init_mutex);
@@ -152,7 +133,7 @@ init_thread_func (gpointer user_data)
     connection_manager = connection_manager_new(data->options.max_connections);
     if (connection_manager == NULL)
         g_error ("failed to allocate connection_manager");
-    g_debug ("ConnectionManager: 0x%" PRIxPTR, (uintptr_t)connection_manager);
+    g_debug ("%s: ConnectionManager: %p", __func__, objid (connection_manager));
     /* setup IpcFrontend */
     data->ipc_frontend =
         IPC_FRONTEND (ipc_frontend_dbus_new (data->options.bus,
@@ -170,18 +151,19 @@ init_thread_func (gpointer user_data)
     ipc_frontend_connect (data->ipc_frontend,
                           &data->init_mutex);
 
-    /**
-     * this isn't strictly necessary but it allows us to detect a failure in
-     * the TCTI before we start communicating with clients
-     */
-    rc = tcti_initialize (data->tcti);
-    if (rc != TSS2_RC_SUCCESS) {
-        tabrmd_critical ("TCTI initialization failed: 0x%x", rc);
+    tcti_factory = tcti_factory_new (data->options.tcti_filename,
+                                     data->options.tcti_conf);
+    tcti = tcti_factory_create (tcti_factory);
+    if (tcti == NULL) {
+        tabrmd_critical ("%s: failed to create TCTI with name \"%s\" and conf "
+                         "\"%s\"", __func__, data->options.tcti_filename,
+                         data->options.tcti_conf);
     }
-
-    data->access_broker = access_broker_new (data->tcti);
-    g_debug ("created AccessBroker: 0x%" PRIxPTR,
-             (uintptr_t)data->access_broker);
+    g_clear_object (&tcti_factory);
+    data->access_broker = access_broker_new (tcti);
+    g_debug ("%s: created AccessBroker: %p", __func__,
+             objid (data->access_broker));
+    g_clear_object (&tcti);
     rc = access_broker_init_tpm (data->access_broker);
     if (rc != TSS2_RC_SUCCESS)
         g_error ("failed to initialize AccessBroker: 0x%" PRIx32, rc);
@@ -193,27 +175,27 @@ init_thread_func (gpointer user_data)
      * pipeline.
      */
     command_attrs = command_attrs_new ();
-    g_debug ("created CommandAttrs: 0x%" PRIxPTR, (uintptr_t)command_attrs);
+    g_debug ("%s: created CommandAttrs: %p", __func__, objid (command_attrs));
     ret = command_attrs_init_tpm (command_attrs, data->access_broker);
     if (ret != 0)
-        g_error ("failed to initialize CommandAttribute object: 0x%" PRIxPTR,
-                 (uintptr_t)command_attrs);
+        g_error ("%s: failed to initialize CommandAttribute object: %p",
+                 __func__, objid (command_attrs));
 
     data->command_source =
         command_source_new (connection_manager, command_attrs);
     g_object_unref (connection_manager);
-    g_debug ("created command source: 0x%" PRIxPTR,
-             (uintptr_t)data->command_source);
+    g_debug ("%s: created command source: %p", __func__,
+             objid (data->command_source));
     session_list = session_list_new (data->options.max_sessions,
                                      SESSION_LIST_MAX_ABANDONED_DEFAULT);
     data->resource_manager = resource_manager_new (data->access_broker,
                                                    session_list);
     g_clear_object (&session_list);
-    g_debug ("created ResourceManager: 0x%" PRIxPTR,
-             (uintptr_t)data->resource_manager);
+    g_debug ("%s: created ResourceManager: %p", __func__,
+             objid (data->resource_manager));
     data->response_sink = response_sink_new ();
-    g_debug ("created response source: 0x%" PRIxPTR,
-             (uintptr_t)data->response_sink);
+    g_debug ("%s: created response source: %p", __func__,
+             objid (data->response_sink));
     g_object_unref (command_attrs);
     g_object_unref (data->access_broker);
     /**
@@ -444,6 +426,7 @@ main (int argc, char *argv[])
     gmain_data_t gmain_data = { .options = TABRMD_OPTIONS_INIT_DEFAULT };
     GThread *init_thread;
 
+    util_init ();
     g_info ("tabrmd startup");
     parse_opts (argc, argv, &gmain_data.options);
     if (geteuid() == 0 && ! gmain_data.options.allow_root) {
@@ -451,8 +434,6 @@ main (int argc, char *argv[])
         return 1;
     }
 
-    gmain_data.tcti = TCTI (tcti_dynamic_new (gmain_data.options.tcti_filename,
-                                              gmain_data.options.tcti_conf));
     g_mutex_init (&gmain_data.init_mutex);
     gmain_data.loop = g_main_loop_new (NULL, FALSE);
     /*
@@ -476,6 +457,5 @@ main (int argc, char *argv[])
     thread_cleanup (THREAD (gmain_data.response_sink));
     /* clean up what remains */
     g_object_unref (gmain_data.random);
-    g_object_unref (gmain_data.tcti);
     return 0;
 }
