@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <fcntl.h>
@@ -66,8 +45,7 @@ tss2_tcti_tabrmd_transmit (TSS2_TCTI_CONTEXT *context,
     }
     g_debug_bytes (command, size, 16, 4);
     ostream = g_io_stream_get_output_stream (TSS2_TCTI_TABRMD_IOSTREAM (context));
-    g_debug ("blocking write on iostream: 0x%" PRIxPTR,
-             (uintptr_t)ostream);
+    g_debug ("%s: blocking write on ostream", __func__);
     write_ret = write_all (ostream, command, size);
     /* should switch on possible errors to translate to TSS2 error codes */
     switch (write_ret) {
@@ -470,8 +448,6 @@ tabrmd_kv_callback (const key_value_t *key_value,
 {
     tabrmd_conf_t *tabrmd_conf = (tabrmd_conf_t*)user_data;
 
-    g_debug ("%s with key_value: 0x%" PRIxPTR " and user_data: 0x%" PRIxPTR,
-             __func__, (uintptr_t)key_value, (uintptr_t)user_data);
     if (key_value == NULL || user_data == NULL) {
         g_warning ("%s passed NULL parameter", __func__);
         return TSS2_TCTI_RC_GENERAL_FAILURE;
