@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <inttypes.h>
 #include <stdint.h>
@@ -183,7 +162,7 @@ tpm2_command_get_property (GObject     *object,
 {
     Tpm2Command *self = TPM2_COMMAND (object);
 
-    g_debug ("tpm2_command_get_property: 0x%" PRIxPTR, (uintptr_t)self);
+    g_debug ("%s: %p", __func__, objid (self));
     switch (property_id) {
     case PROP_ATTRIBUTES:
         g_value_set_uint (value, self->attributes);
@@ -207,7 +186,7 @@ tpm2_command_dispose (GObject *obj)
 {
     Tpm2Command *cmd = TPM2_COMMAND (obj);
 
-    g_debug ("%s: Tpm2Command 0x%" PRIxPTR, __func__, (uintptr_t)cmd);
+    g_debug ("%s: Tpm2Command %p", __func__, objid (cmd));
     g_clear_object (&cmd->connection);
     G_OBJECT_CLASS (tpm2_command_parent_class)->dispose (obj);
 }
@@ -661,8 +640,8 @@ tpm2_command_get_auths_size (Tpm2Command *command)
         return 0;
     }
     if (!tpm2_command_has_auths (command)) {
-        g_warning ("tpm2_command_get_auths_size, Tpm2Command 0x%" PRIxPTR
-                   " has no auths", (uintptr_t)command);
+        g_warning ("%s: Tpm2Command %p has no auths",
+                   __func__, objid (command));
         return 0;
     }
     auth_size_end = AUTH_AREA_SIZE_END_OFFSET (command);
@@ -746,11 +725,9 @@ tpm2_command_foreach_auth (Tpm2Command *command,
          offset = AUTH_AUTH_BUF_END_OFFSET   (command, offset))
     {
         size_t offset_tmp = offset;
-        g_debug ("invoking callback at 0x%" PRIxPTR " with authorization at "
-                 "offset: %zu and user data: 0x%" PRIxPTR,
-                 (uintptr_t)callback,
-                 offset_tmp,
-                 (uintptr_t)user_data);
+        g_debug ("%s: invoking callback at %p with authorization at offset: "
+                 "%zu and user data: %p", __func__, objid (callback),
+                 offset_tmp, objid (user_data));
         callback (&offset_tmp, user_data);
     }
 
