@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
  * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <inttypes.h>
@@ -109,7 +88,7 @@ tpm2_response_get_property (GObject     *object,
 {
     Tpm2Response *self = TPM2_RESPONSE (object);
 
-    g_debug ("tpm2_response_get_property: 0x%" PRIxPTR, (uintptr_t)self);
+    g_debug ("%s: %p", __func__, objid (self));
     switch (property_id) {
     case PROP_ATTRIBUTES:
         g_value_set_uint (value, self->attributes);
@@ -133,7 +112,7 @@ tpm2_response_dispose (GObject *obj)
 {
     Tpm2Response *self = TPM2_RESPONSE (obj);
 
-    g_debug ("%s: Tpm2Response: 0x%" PRIxPTR, __func__, (uintptr_t)self);
+    g_debug ("%s: Tpm2Response: %p", __func__, objid (self));
     g_clear_object (&self->connection);
     G_OBJECT_CLASS (tpm2_response_parent_class)->dispose (obj);
 }
@@ -212,8 +191,9 @@ tpm2_response_new (Connection     *connection,
                    size_t           buffer_size,
                    TPMA_CC          attributes)
 {
-    g_debug ("%s: connection: 0x%" PRIxPTR " buffer: 0x%" PRIxPTR " size: 0x%zx attrs: 0x%" PRIx32,
-             __func__, (uintptr_t)connection, (uintptr_t)buffer, buffer_size, attributes);
+    g_debug ("%s: connection: %p buffer: %p size: 0x%zx attrs: 0x%" PRIx32,
+             __func__, objid (connection), objid (buffer), buffer_size,
+             attributes);
     return TPM2_RESPONSE (g_object_new (TYPE_TPM2_RESPONSE,
                                         "attributes", attributes,
                                        "buffer",  buffer,
@@ -274,10 +254,11 @@ tpm2_response_new_context_load (Connection *connection,
                    __func__, rc);
         goto out;
     }
-    g_debug ("%s: Generating response for SaveContext from connection 0x%" PRIxPTR, __func__, (uintptr_t)connection);
+    g_debug ("%s: generating response for SaveContext from connection %p",
+             __func__, objid (connection));
     response = tpm2_response_new (connection, buf, offset, 0x10000161);
-    g_debug ("%s generated Tpm2Response object: 0x%" PRIxPTR " for connection: 0x%" PRIxPTR,
-             __func__, (uintptr_t)response, (uintptr_t)connection);
+    g_debug ("%s: generated Tpm2Response object: %p for connection: %p",
+             __func__, objid (response), objid (connection));
 out:
     if (response == NULL) {
         g_free (buf);
@@ -315,10 +296,11 @@ tpm2_response_new_context_save (Connection *connection,
                    __func__, rc);
         goto out;
     }
-    g_debug ("%s: Generating response for SaveContext from connection 0x%" PRIxPTR, __func__, (uintptr_t)connection);
+    g_debug ("%s: generating response for SaveContext from connection %p",
+             __func__, objid (connection));
     response = tpm2_response_new (connection, buf, TPM_HEADER_SIZE + size_buf->size, 0x02000162);
-    g_debug ("%s generated Tpm2Response object: 0x%" PRIxPTR " for connection: 0x%" PRIxPTR,
-             __func__, (uintptr_t)response, (uintptr_t)connection);
+    g_debug ("%s generated Tpm2Response object: %p for connection: %p",
+             __func__, objid (response), objid (connection));
 out:
     if (response == NULL) {
         g_free (buf);
