@@ -1,44 +1,33 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
- * Copyright (c) 2017, Intel Corporation
+ * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <gio/gunixfdlist.h>
 #include <glib.h>
 #include <inttypes.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <sys/socket.h>
 
 #include <setjmp.h>
 #include <cmocka.h>
 
-#include <sapi/tpm20.h>
+#include <tss2/tss2_tpm2_types.h>
 
-#include "tcti-tabrmd.h"
+#include "tabrmd.h"
+#include "tss2-tcti-tabrmd.h"
 #include "tcti-tabrmd-priv.h"
 #include "tpm2-header.h"
+#include "util.h"
+
+#if defined(__linux__) || defined(__unix__) || defined(__APPLE__)
+#define TSS2_TCTI_POLL_HANDLE_ZERO_INIT { .fd = 0, .events = 0, .revents = 0 }
+#else
+#define TSS2_TCTI_POLL_HANDLE_ZERO_INIT { 0 }
+#endif
 
 /*
  * when given an NULL context and a pointer to a size_t, set the size_t
@@ -48,8 +37,9 @@ static void
 tcti_tabrmd_init_size_test (void **state)
 {
     size_t tcti_size;
+    UNUSED_PARAM(state);
 
-    tss2_tcti_tabrmd_init (NULL, &tcti_size);
+    Tss2_Tcti_Tabrmd_Init (NULL, &tcti_size, NULL);
     assert_int_equal (tcti_size, sizeof (TSS2_TCTI_TABRMD_CONTEXT));
 }
 /*
@@ -61,8 +51,9 @@ tcti_tabrmd_init_success_return_value_test (void **state)
 {
     size_t tcti_size;
     TSS2_RC ret;
+    UNUSED_PARAM(state);
 
-    ret = tss2_tcti_tabrmd_init (NULL, &tcti_size);
+    ret = Tss2_Tcti_Tabrmd_Init (NULL, &tcti_size, NULL);
     assert_int_equal (ret, TSS2_RC_SUCCESS);
 }
 /*
@@ -73,10 +64,253 @@ static void
 tcti_tabrmd_init_allnull_is_bad_value_test (void **state)
 {
     TSS2_RC ret;
+    UNUSED_PARAM(state);
 
-    ret = tss2_tcti_tabrmd_init (NULL, NULL);
+    ret = Tss2_Tcti_Tabrmd_Init (NULL, NULL, NULL);
     assert_int_equal (ret, TSS2_TCTI_RC_BAD_VALUE);
 }
+/*
+ * Ensure that the standard Tss2_Tcti_Info discovery function returns a
+ * reference to the config structure.
+ */
+static void
+tcti_tabrmd_info_test (void **state)
+{
+    const TSS2_TCTI_INFO *tcti_info;
+    UNUSED_PARAM(state);
+
+    /*
+     * This function isn't meant to be called directly. We do it here for the
+     * test coverage
+     */
+    tcti_info = Tss2_Tcti_Info ();
+    assert_non_null (tcti_info);
+    assert_non_null (tcti_info->init);
+}
+/*
+ * Ensure that when we pass the string "session" to the
+ * tabrmd_bus_type_from_str returns G_BUS_TYPE_SESSION.
+ */
+static void
+tcti_tabrmd_bus_type_from_str_session_test (void **state)
+{
+    UNUSED_PARAM(state);
+    assert_int_equal (tabrmd_bus_type_from_str ("session"),
+                      G_BUS_TYPE_SESSION);
+}
+/*
+ * Ensure that when we pass the string "system" to the
+ * tabrmd_bus_type_from_str returns G_BUS_TYPE_SYSTEM.
+ */
+static void
+tcti_tabrmd_bus_type_from_str_system_test (void **state)
+{
+    UNUSED_PARAM(state);
+    assert_int_equal (tabrmd_bus_type_from_str ("system"),
+                      G_BUS_TYPE_SYSTEM);
+}
+/*
+ * Ensure that when we pass an unexpected string to the
+ * tabrmd_bus_type_from_str returns G_BUS_TYPE_NONE.
+ */
+static void
+tcti_tabrmd_bus_type_from_str_bad_test (void **state)
+{
+    UNUSED_PARAM(state);
+    assert_int_equal (tabrmd_bus_type_from_str ("foobar"),
+                      G_BUS_TYPE_NONE);
+}
+/*
+ * Ensure that when we pass the key "bus_name" and value "any string"
+ * to tabrmd_kv_callback that it returns an RC indicating success while
+ * the conf structure 'bus_name' field is set to the value string.
+ */
+static void
+tcti_tabrmd_kv_callback_name_test (void **state)
+{
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    key_value_t key_value = { 
+        .key = "bus_name",
+        .value = "foo.bar",
+    };
+    TSS2_RC rc;
+    UNUSED_PARAM(state);
+
+    rc = tabrmd_kv_callback (&key_value, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_string_equal ("foo.bar", conf.bus_name);
+}
+/*
+ * Ensure that when we pass the key "bus_type" and the value "system"
+ * to tabrmd_kv_callback that it returns an RC indicating success while
+ * the conf structure 'bus_type' field is set to G_BUS_TYPE_SYSTEM.
+ */
+static void
+tcti_tabrmd_kv_callback_type_good_test (void **state)
+{
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    key_value_t key_value = { 
+        .key = "bus_type",
+        .value = "system",
+    };
+    TSS2_RC rc;
+    UNUSED_PARAM(state);
+
+    rc = tabrmd_kv_callback (&key_value, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_int_equal (conf.bus_type, G_BUS_TYPE_SYSTEM);
+}
+/*
+ * Ensure that when we pass the key "bus_type" and with an invalid value
+ * string (not "system" or "session") that it returns the BAD_VALUE RC and
+ * sets the 'bus_type' field of the conf structure to
+ * G_BUS_TYPE_NONE.
+ */
+static void
+tcti_tabrmd_kv_callback_type_bad_test (void **state)
+{
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    key_value_t key_value = { 
+        .key = "bus_type",
+        .value = "foo",
+    };
+    TSS2_RC rc;
+    UNUSED_PARAM(state);
+
+    rc = tabrmd_kv_callback (&key_value, &conf);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_VALUE);
+    assert_int_equal (conf.bus_type, G_BUS_TYPE_NONE);
+}
+/*
+ * Ensure that when we pass an invalid key (not 'bus_type' or 'bus_name')
+ * that it returns an RC indicating BAD_VALUE.
+ */
+static void
+tcti_tabrmd_kv_callback_bad_key_test (void **state)
+{
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    key_value_t key_value = { 
+        .key = "foo",
+        .value = "bar",
+    };
+    TSS2_RC rc;
+    UNUSED_PARAM(state);
+
+    rc = tabrmd_kv_callback (&key_value, &conf);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_VALUE);
+}
+/*
+ * Ensure that a common config string selecting the session bus with
+ * a user supplied name is parsed correctly.
+ */
+static void
+tcti_tabrmd_conf_parse_named_session_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_type=session,bus_name=com.example.Session";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_string_equal (conf.bus_name, "com.example.Session");
+    assert_int_equal (conf.bus_type, G_BUS_TYPE_SESSION);
+}
+/*
+ * Ensure that a common config string selecting the system bus with
+ * a user supplied name is parsed correctly.
+ */
+static void
+tcti_tabrmd_conf_parse_named_system_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_type=system,bus_name=com.example.System";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_string_equal (conf.bus_name, "com.example.System");
+    assert_int_equal (conf.bus_type, G_BUS_TYPE_SYSTEM);
+}
+/*
+ * Ensure that an unknown bus_type string results in the appropriate RC.
+ */
+static void
+tcti_tabrmd_conf_parse_bad_type_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_type=foobar";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_VALUE);
+}
+/*
+ * Ensure that a config string that omits the bus_name results in a conf
+ * structure with the associated field set to the default.
+ */
+static void
+tcti_tabrmd_conf_parse_no_name_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_type=session";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_string_equal (conf.bus_name, TABRMD_DBUS_NAME_DEFAULT);
+    assert_int_equal (conf.bus_type, G_BUS_TYPE_SESSION);
+}
+/*
+ * Ensure that a config string that omits the bus_type results in a conf
+ * structure with the associated field set to the default.
+ */
+static void
+tcti_tabrmd_conf_parse_no_type_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_name=com.example.FooBar";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_RC_SUCCESS);
+    assert_string_equal (conf.bus_name, "com.example.FooBar");
+    assert_int_equal (conf.bus_type, TABRMD_DBUS_TYPE_DEFAULT);
+}
+/*
+ * Ensure that a missing value results in the appropriate RC.
+ */
+static void
+tcti_tabrmd_conf_parse_no_value_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "bus_name=";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_VALUE);
+}
+/*
+ * Ensure that a missing key results in the appropriate RC
+ */
+static void
+tcti_tabrmd_conf_parse_no_key_test (void **state)
+{
+    TSS2_RC rc;
+    tabrmd_conf_t conf = TABRMD_CONF_INIT_DEFAULT;
+    char conf_str[] = "=some-string";
+    UNUSED_PARAM(state);
+
+    rc = parse_key_value_string (conf_str, tabrmd_kv_callback, &conf);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_VALUE);
+}
+/*
+ */
 /*
  * This is a mock function to control return values from the connection
  * creation logic that invokes the DBus "CreateConnection" function exposed
@@ -98,6 +332,14 @@ __wrap_g_dbus_proxy_call_with_unix_fd_list_sync (
     GVariant *variant_array[2] = { 0 }, *variant_tuple;
     gint client_fd;
     guint64 id;
+    UNUSED_PARAM(proxy);
+    UNUSED_PARAM(method_name);
+    UNUSED_PARAM(parameters);
+    UNUSED_PARAM(flags);
+    UNUSED_PARAM(timeout_msec);
+    UNUSED_PARAM(fd_list);
+    UNUSED_PARAM(cancellable);
+    UNUSED_PARAM(error);
 
     client_fd = mock_type (gint);
     id = mock_type (guint64);
@@ -125,6 +367,11 @@ __wrap_tcti_tabrmd_call_cancel_sync (
     GCancellable *cancellable,
     GError **error)
 {
+    UNUSED_PARAM(proxy);
+    UNUSED_PARAM(arg_id);
+    UNUSED_PARAM(cancellable);
+    UNUSED_PARAM(error);
+
     *out_return_code = mock_type (guint);
     return mock_type (gboolean);
 }
@@ -142,6 +389,12 @@ __wrap_tcti_tabrmd_call_set_locality_sync (
     GCancellable *cancellable,
     GError **error)
 {
+    UNUSED_PARAM(proxy);
+    UNUSED_PARAM(arg_id);
+    UNUSED_PARAM(arg_locality);
+    UNUSED_PARAM(cancellable);
+    UNUSED_PARAM(error);
+
     *out_return_code = mock_type (guint);
     return mock_type (gboolean);
 }
@@ -169,13 +422,15 @@ tcti_tabrmd_setup (void **state)
     guint64 id = 666;
 
     data = calloc (1, sizeof (data_t));
-    ret = tss2_tcti_tabrmd_init (NULL, &tcti_size);
+    ret = Tss2_Tcti_Tabrmd_Init (NULL, &tcti_size, NULL);
     if (ret != TSS2_RC_SUCCESS) {
+        free (data);
         printf ("tss2_tcti_tabrmd_init failed: %d\n", ret);
         return 1;
     }
     data->context = calloc (1, tcti_size);
     if (data->context == NULL) {
+        free (data);
         perror ("calloc");
         return 1;
     }
@@ -187,11 +442,7 @@ tcti_tabrmd_setup (void **state)
                  data->client_fd);
     data->id = id;
     will_return (__wrap_g_dbus_proxy_call_with_unix_fd_list_sync, id);
-    g_debug ("about to call real tss2_tcti_tabrmd_init function");
-    ret = tss2_tcti_tabrmd_init_full (data->context,
-                                      0,
-                                      TCTI_TABRMD_DBUS_TYPE_SESSION,
-                                      TCTI_TABRMD_DBUS_NAME_DEFAULT);
+    ret = Tss2_Tcti_Tabrmd_Init (data->context, &tcti_size, "bus_type=session");
     assert_int_equal (ret, TSS2_RC_SUCCESS);
 
     *state = data;
@@ -206,7 +457,7 @@ tcti_tabrmd_teardown (void **state)
 {
     data_t *data = *state;
 
-    tss2_tcti_finalize (data->context);
+    Tss2_Tcti_Finalize (data->context);
     close (data->client_fd);
     close (data->server_fd);
     if (data->context)
@@ -235,7 +486,7 @@ tcti_tabrmd_version_test (void **state)
 {
     data_t *data = *state;
 
-    assert_int_equal (TSS2_TCTI_VERSION (data->context), 1);
+    assert_int_equal (TSS2_TCTI_VERSION (data->context), TSS2_TCTI_TABRMD_VERSION);
 }
 /*
  * Ensure that after initialization the 'id' value set for the connection is
@@ -264,47 +515,52 @@ static void
 tcti_tabrmd_transmit_null_context_test (void **state)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(state);
 
-    rc = tss2_tcti_transmit (NULL, 5, NULL);
-    assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
+    rc = Tss2_Tcti_Transmit (NULL, 5, NULL);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
 }
 static void
 tcti_tabrmd_receive_null_context_test (void **state)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(state);
 
-    rc = tss2_tcti_receive (NULL, NULL, NULL, TSS2_TCTI_TIMEOUT_BLOCK);
-    assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
+    rc = Tss2_Tcti_Receive (NULL, NULL, NULL, TSS2_TCTI_TIMEOUT_BLOCK);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
 }
 static void
 tcti_tabrmd_cancel_null_context_test (void **state)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(state);
 
-    rc = tss2_tcti_cancel (NULL);
-    assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
+    rc = Tss2_Tcti_Cancel (NULL);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
 }
 static void
 tcti_tabrmd_get_poll_handles_null_context_test (void **state)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(state);
 
-    rc = tss2_tcti_get_poll_handles (NULL, NULL, NULL);
-    assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
+    rc = Tss2_Tcti_GetPollHandles (NULL, NULL, NULL);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
 }
 static void
 tcti_tabrmd_set_locality_null_context_test (void **state)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(state);
 
-    rc = tss2_tcti_set_locality (NULL, 5);
-    assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
+    rc = Tss2_Tcti_SetLocality (NULL, 5);
+    assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
 }
 /*
  * This test makes a single call to the transmit function in the the
  * TSS2_TCTI_CONTEXT function pointer table. It sends a fixed 12 byte TPM
  * command buffer:
- * tag:     TPM_ST_NO_SESSIONS
+ * tag:     TPM2_ST_NO_SESSIONS
  * size:    12 bytes
  * command: 0x0
  * data:    0x01, 0x02
@@ -322,10 +578,12 @@ tcti_tabrmd_transmit_success_test (void **state)
     TSS2_RC rc;
     ssize_t ret;
 
-    rc = tss2_tcti_transmit (data->context, size, command_in);
+    rc = Tss2_Tcti_Transmit (data->context, size, command_in);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
     ret = read (data->server_fd, command_out, size);
     assert_int_equal (ret, size);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
     assert_memory_equal (command_in, command_out, size);
@@ -343,7 +601,7 @@ tcti_tabrmd_transmit_bad_magic_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_MAGIC (data->context) = 1;
-    rc = tss2_tcti_transmit (data->context, size, command);
+    rc = Tss2_Tcti_Transmit (data->context, size, command);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
@@ -361,7 +619,7 @@ tcti_tabrmd_transmit_bad_version_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_VERSION (data->context) = -1;
-    rc = tss2_tcti_transmit (data->context, size, command);
+    rc = Tss2_Tcti_Transmit (data->context, size, command);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
@@ -379,7 +637,7 @@ tcti_tabrmd_transmit_bad_sequence_receive_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_RECEIVE;
-    rc = tss2_tcti_transmit (data->context, size, command);
+    rc = Tss2_Tcti_Transmit (data->context, size, command);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
@@ -397,7 +655,7 @@ tcti_tabrmd_transmit_bad_sequence_final_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_FINAL;
-    rc = tss2_tcti_transmit (data->context, size, command);
+    rc = Tss2_Tcti_Transmit (data->context, size, command);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_FINAL);
@@ -435,6 +693,7 @@ __wrap_read_data (int       fd,
     uint8_t *buf_in;
     size_t count_in;
     int ret;
+    UNUSED_PARAM(fd);
 
     buf_in   = mock_type (uint8_t*);
     count_in = mock_type (size_t);
@@ -466,6 +725,7 @@ __wrap_poll (struct pollfd *fds,
              nfds_t         nfds,
              int            timeout)
 {
+    UNUSED_PARAM(timeout);
     assert_int_equal (nfds, 1);
     fds [0].revents = mock_type (short);
     errno = mock_type (int);
@@ -498,11 +758,13 @@ tcti_tabrmd_receive_success_test (void **state)
     will_return (__wrap_read_data, command_in);
     will_return (__wrap_read_data, sizeof (command_in) - TPM_HEADER_SIZE);
     will_return (__wrap_read_data, 0);
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             command_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
     assert_int_equal (size, sizeof (command_in));
@@ -539,11 +801,13 @@ tcti_tabrmd_receive_poll_eintr_test (void **state)
     will_return (__wrap_read_data, command_in);
     will_return (__wrap_read_data, sizeof (command_in));
     will_return (__wrap_read_data, 0);
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             command_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
     assert_int_equal (size, sizeof (command_in));
@@ -562,11 +826,13 @@ tcti_tabrmd_receive_poll_fail_test (void **state)
     uint8_t command_out [sizeof (command_in)] = { 0 };
     TSS2_RC rc;
 
+    UNUSED_VAR(command_in);
+
     will_return (__wrap_poll, 0);
     will_return (__wrap_poll, ENOMEM);
     will_return (__wrap_poll, -1);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             command_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -582,6 +848,8 @@ tcti_tabrmd_receive_poll_timeout_test (void **state)
     uint8_t command_in [] = { 0x80, 0x02,
                               0x00, 0x00, 0x00, 0x0a,
                               0x00, 0x00, 0x00, 0x00 };
+    UNUSED_VAR(command_in);
+
     size_t size = sizeof (command_in);
     uint8_t command_out [sizeof (command_in)] = { 0 };
     TSS2_RC rc;
@@ -590,7 +858,7 @@ tcti_tabrmd_receive_poll_timeout_test (void **state)
     will_return (__wrap_poll, 0);
     will_return (__wrap_poll, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             command_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -610,7 +878,7 @@ tcti_tabrmd_receive_bad_magic_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_MAGIC (data->context) = 1;
-    rc = tss2_tcti_receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
+    rc = Tss2_Tcti_Receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
@@ -628,7 +896,7 @@ tcti_tabrmd_receive_bad_version_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_VERSION (data->context) = -1;
-    rc = tss2_tcti_receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
+    rc = Tss2_Tcti_Receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_CONTEXT);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
@@ -646,7 +914,7 @@ tcti_tabrmd_receive_bad_sequence_transmit_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_TRANSMIT;
-    rc = tss2_tcti_receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
+    rc = Tss2_Tcti_Receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
@@ -664,7 +932,7 @@ tcti_tabrmd_receive_bad_sequence_final_test (void **state)
     size_t size = 12;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_FINAL;
-    rc = tss2_tcti_receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
+    rc = Tss2_Tcti_Receive (data->context, &size, buf, TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_FINAL);
@@ -688,7 +956,9 @@ tcti_tabrmd_receive_bad_timeout_test (void **state)
     uint8_t command_out [sizeof (command_in)] = { 0 };
     TSS2_RC rc;
 
-    rc = tss2_tcti_receive (data->context,
+    UNUSED_VAR(command_in);
+
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             command_out,
                             -2);
@@ -704,7 +974,7 @@ tcti_tabrmd_receive_null_size_test (void **state)
     uint8_t command_out [TPM_HEADER_SIZE] = { 0, };
     TSS2_RC rc;
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             NULL,
                             command_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -720,7 +990,7 @@ tcti_tabrmd_receive_null_response_size_nonzero_test (void **state)
     size_t size = 1;
     TSS2_RC rc;
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             NULL,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -738,11 +1008,13 @@ tcti_tabrmd_receive_size_lt_header_test (void **state)
     size_t size = sizeof (response) - 1;
     TSS2_RC rc;
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             response,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_INSUFFICIENT_BUFFER);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
 }
@@ -770,11 +1042,13 @@ tcti_tabrmd_receive_size_lt_body_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE);
     will_return (__wrap_read_data, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_INSUFFICIENT_BUFFER);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
 }
@@ -803,11 +1077,13 @@ tcti_tabrmd_receive_error_first_read_test (void **state)
     will_return (__wrap_read_data, 0);
     will_return (__wrap_read_data, G_IO_ERROR_WOULD_BLOCK);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_TRY_AGAIN);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
 }
@@ -835,11 +1111,13 @@ tcti_tabrmd_receive_malformed_header_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE);
     will_return (__wrap_read_data, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_TCTI_RC_MALFORMED_RESPONSE);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
 }
@@ -873,7 +1151,7 @@ tcti_tabrmd_receive_two_reads_header_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE / 2);
     will_return (__wrap_read_data, G_IO_ERROR_WOULD_BLOCK);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -889,7 +1167,7 @@ tcti_tabrmd_receive_two_reads_header_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE / 2);
     will_return (__wrap_read_data, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
@@ -922,11 +1200,13 @@ tcti_tabrmd_receive_get_size_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE);
     will_return (__wrap_read_data, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             NULL,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
     assert_int_equal (size, 0x0e);
@@ -956,12 +1236,14 @@ tcti_tabrmd_receive_get_size_and_body_test (void **state)
     will_return (__wrap_read_data, TPM_HEADER_SIZE);
     will_return (__wrap_read_data, 0);
 
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             NULL,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
-    assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
+    assert_non_null(data->context);
+    if ((data != NULL  && data->context != NULL))
+        assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
     assert_int_equal (size, 0x0e);
 
@@ -973,11 +1255,13 @@ tcti_tabrmd_receive_get_size_and_body_test (void **state)
     will_return (__wrap_read_data, 0);
 
     size = sizeof (buffer_in) + 1;
-    rc = tss2_tcti_receive (data->context,
+    rc = Tss2_Tcti_Receive (data->context,
                             &size,
                             buffer_out,
                             TSS2_TCTI_TIMEOUT_BLOCK);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
     assert_memory_equal (buffer_in, buffer_out, sizeof (buffer_in));
@@ -996,8 +1280,10 @@ tcti_tabrmd_cancel_test (void **state)
 
     will_return (__wrap_tcti_tabrmd_call_cancel_sync, TSS2_RC_SUCCESS);
     will_return (__wrap_tcti_tabrmd_call_cancel_sync, TRUE);
-    rc = tss2_tcti_cancel (data->context);
+    rc = Tss2_Tcti_Cancel (data->context);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_RECEIVE);
 }
@@ -1012,7 +1298,7 @@ tcti_tabrmd_cancel_bad_sequence_test (void **state)
     TSS2_RC rc;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_TRANSMIT;
-    rc = tss2_tcti_cancel (data->context);
+    rc = Tss2_Tcti_Cancel (data->context);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
     assert_int_equal (TSS2_TCTI_TABRMD_STATE (data->context),
                       TABRMD_STATE_TRANSMIT);
@@ -1027,7 +1313,7 @@ tcti_tabrmd_get_poll_handles_all_null_test (void **state)
     data_t *data = *state;
     TSS2_RC rc;
 
-    rc = tss2_tcti_get_poll_handles (data->context, NULL, NULL);
+    rc = Tss2_Tcti_GetPollHandles (data->context, NULL, NULL);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_REFERENCE);
 }
 /*
@@ -1042,7 +1328,7 @@ tcti_tabrmd_get_poll_handles_count_test (void **state)
     size_t num_handles = 0;
     TSS2_RC rc;
 
-    rc = tss2_tcti_get_poll_handles (data->context, NULL, &num_handles);
+    rc = Tss2_Tcti_GetPollHandles (data->context, NULL, &num_handles);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
     assert_true (num_handles > 0);
 }
@@ -1055,11 +1341,15 @@ static void
 tcti_tabrmd_get_poll_handles_bad_handles_count_test (void **state)
 {
     data_t *data = *state;
-    TSS2_TCTI_POLL_HANDLE handles[5] = { 0 };
+    TSS2_TCTI_POLL_HANDLE handles[5] = {
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT, TSS2_TCTI_POLL_HANDLE_ZERO_INIT,
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT, TSS2_TCTI_POLL_HANDLE_ZERO_INIT,
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT
+    };
     size_t num_handles = 0;
     TSS2_RC rc;
 
-    rc = tss2_tcti_get_poll_handles (data->context, handles, &num_handles);
+    rc = Tss2_Tcti_GetPollHandles (data->context, handles, &num_handles);
     assert_int_equal (rc, TSS2_TCTI_RC_INSUFFICIENT_BUFFER);
 }
 /*
@@ -1072,14 +1362,20 @@ static void
 tcti_tabrmd_get_poll_handles_handles_test (void **state)
 {
     data_t *data = *state;
-    TSS2_TCTI_POLL_HANDLE handles[5] = { 0 };
+    TSS2_TCTI_POLL_HANDLE handles[5] = {
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT, TSS2_TCTI_POLL_HANDLE_ZERO_INIT,
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT, TSS2_TCTI_POLL_HANDLE_ZERO_INIT,
+        TSS2_TCTI_POLL_HANDLE_ZERO_INIT
+    };
     size_t num_handles = 5;
     TSS2_RC rc;
-    int fd;
+    int fd = -1;
 
-    rc = tss2_tcti_get_poll_handles (data->context, handles, &num_handles);
+    rc = Tss2_Tcti_GetPollHandles (data->context, handles, &num_handles);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
     assert_int_equal (1, num_handles);
+    ASSERT_NON_NULL(data);
+    ASSERT_NON_NULL(data->context);
     fd = TSS2_TCTI_TABRMD_FD (data->context);
     assert_int_equal (handles [0].fd, fd);
 }
@@ -1097,7 +1393,7 @@ tcti_tabrmd_set_locality_test (void **state)
 
     will_return (__wrap_tcti_tabrmd_call_set_locality_sync, TSS2_RC_SUCCESS);
     will_return (__wrap_tcti_tabrmd_call_set_locality_sync, TRUE);
-    rc = tss2_tcti_set_locality (data->context, locality);
+    rc = Tss2_Tcti_SetLocality (data->context, locality);
     assert_int_equal (rc, TSS2_RC_SUCCESS);
 }
 /*
@@ -1112,17 +1408,33 @@ tcti_tabrmd_set_locality_bad_sequence_test (void **state)
     TSS2_RC rc;
 
     TSS2_TCTI_TABRMD_STATE (data->context) = TABRMD_STATE_RECEIVE;
-    rc = tss2_tcti_set_locality (data->context, locality);
+    rc = Tss2_Tcti_SetLocality (data->context, locality);
     assert_int_equal (rc, TSS2_TCTI_RC_BAD_SEQUENCE);
 }
 int
-main(int argc, char* argv[])
+main (void)
 {
+    util_init ();
     const struct CMUnitTest tests[] = {
         cmocka_unit_test (tcti_tabrmd_init_size_test),
         cmocka_unit_test (tcti_tabrmd_init_success_return_value_test),
         cmocka_unit_test (tcti_tabrmd_init_allnull_is_bad_value_test),
         cmocka_unit_test (tcti_tabrmd_init_success_test),
+        cmocka_unit_test (tcti_tabrmd_info_test),
+        cmocka_unit_test (tcti_tabrmd_bus_type_from_str_session_test),
+        cmocka_unit_test (tcti_tabrmd_bus_type_from_str_system_test),
+        cmocka_unit_test (tcti_tabrmd_bus_type_from_str_bad_test),
+        cmocka_unit_test (tcti_tabrmd_kv_callback_name_test),
+        cmocka_unit_test (tcti_tabrmd_kv_callback_type_good_test),
+        cmocka_unit_test (tcti_tabrmd_kv_callback_type_bad_test),
+        cmocka_unit_test (tcti_tabrmd_kv_callback_bad_key_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_named_session_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_named_system_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_bad_type_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_no_name_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_no_type_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_no_value_test),
+        cmocka_unit_test (tcti_tabrmd_conf_parse_no_key_test),
         cmocka_unit_test_setup_teardown (tcti_tabrmd_magic_test,
                                          tcti_tabrmd_setup,
                                          tcti_tabrmd_teardown),
