@@ -1,34 +1,14 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
- * Copyright (c) 2017, Intel Corporation
+ * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <errno.h>
 #include <fcntl.h>
 #include <inttypes.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 
 #include <setjmp.h>
 #include <cmocka.h>
@@ -56,6 +36,11 @@ __wrap_g_output_stream_write (GOutputStream *ostream,
                               GError       **error)
 {
     GError *error_tmp = mock_type (GError*);
+    UNUSED_PARAM(ostream);
+    UNUSED_PARAM(buf);
+    UNUSED_PARAM(count);
+    UNUSED_PARAM(cancellable);
+
     if (error_tmp != NULL && error != NULL) {
         *error = error_tmp;
     }
@@ -66,6 +51,7 @@ void
 write_in_one (void **state)
 {
     ssize_t written;
+    UNUSED_PARAM(state);
 
     will_return (__wrap_g_output_stream_write, NULL);
     will_return (__wrap_g_output_stream_write, WRITE_SIZE);
@@ -77,6 +63,7 @@ void
 write_in_two (void **state)
 {
     ssize_t written;
+    UNUSED_PARAM(state);
 
     will_return (__wrap_g_output_stream_write, NULL);
     will_return (__wrap_g_output_stream_write, 5);
@@ -90,6 +77,7 @@ void
 write_in_three (void **state)
 {
     ssize_t written;
+    UNUSED_PARAM(state);
 
     will_return (__wrap_g_output_stream_write, NULL);
     will_return (__wrap_g_output_stream_write, 3);
@@ -106,6 +94,7 @@ write_error (void **state)
 {
     ssize_t written;
     GError *error;
+    UNUSED_PARAM(state);
 
     /* this is free'd by the 'write_all' function */
     error = g_error_new (UTIL_UNIT_ERROR,
@@ -121,6 +110,7 @@ void
 write_zero (void **state)
 {
     ssize_t written;
+    UNUSED_PARAM(state);
 
     will_return (__wrap_g_output_stream_write, NULL);
     will_return (__wrap_g_output_stream_write, 0);
@@ -146,12 +136,14 @@ __wrap_g_input_stream_read (GInputStream  *istream,
     size_t   buf_index = mock_type (size_t);
     GError  *error_in  = mock_type (GError*);
     ssize_t  ret       = mock_type (ssize_t);
+    UNUSED_PARAM(istream);
+    UNUSED_PARAM(cancellable);
 
     g_debug ("%s", __func__);
     if (error_in != NULL && error != NULL) {
         *error = error_in;
     }
-    /* be careful comparint signed to unsigned values */
+    /* be careful comparing signed to unsigned values */
     if (ret > 0) {
         assert_true (ret <= (ssize_t)count);
         memcpy (buf, &buf_in [buf_index], ret);
@@ -207,6 +199,7 @@ static void
 create_socket_pair_success_test (void **state)
 {
     int ret, client_fd, server_fd;
+    UNUSED_PARAM(state);
 
     ret = create_socket_pair (&client_fd, &server_fd, O_CLOEXEC);
     if (ret == -1)
@@ -660,6 +653,7 @@ read_tpm_buf_alloc_eof_test (void **state)
 {
     uint8_t *buf;
     size_t   buf_size;
+    UNUSED_PARAM(state);
 
     /* prime read to successfully produce the header */
     will_return (__wrap_g_input_stream_read, buf_in);
@@ -672,9 +666,9 @@ read_tpm_buf_alloc_eof_test (void **state)
 }
 
 gint
-main (gint    argc,
-      gchar  *argv[])
+main (void)
 {
+    util_init ();
     const struct CMUnitTest tests[] = {
         cmocka_unit_test (write_in_one),
         cmocka_unit_test (write_in_two),
